# Authors

-----

## Maintainers

- Ofek Lev [:material-web:](https://ofek.dev) [:material-github:](https://github.com/ofek) [:material-twitter:](https://twitter.com/Ofekmeister)

## Contributors

- Amjith Ramanujam [:material-twitter:](https://twitter.com/amjithr)
- Chris Warrick [:material-twitter:](https://twitter.com/Kwpolska)
- Lumír 'Frenzy' Balhar [:material-email:](mailto:frenzy.madness@gmail.com) [:material-twitter:](https://twitter.com/lumirbalhar)
- Ofek Lev [:material-web:](https://ofek.dev) [:material-github:](https://github.com/ofek) [:material-twitter:](https://twitter.com/Ofekmeister)
- Philip Blair [:material-email:](mailto:philip@pblair.org)
